//
// C++ Interface: CWavesysEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CWAVESYSEDITDLG_H
#define CWAVESYSEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_wavesysdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CWavesysEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CWavesysEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CWavesysEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
 
private slots:
 
protected:
    Ui::WaveSysEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
